Place Type - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Place Type

Place types are what indicate what kind of a place it is, such as a country, a city, or a house number. They inherit from `betty.ancestry.place_type.PlaceType`.

## Built-in place types

`borough` (`betty.ancestry.place_type.place_types.Borough`)

  A borough.

`building` (`betty.ancestry.place_type.place_types.Building`)

  A building.

`city` (`betty.ancestry.place_type.place_types.City`)

  A city.

`country` (`betty.ancestry.place_type.place_types.Country`)

  A country.

`county` (`betty.ancestry.place_type.place_types.County`)

  A county.

`department` (`betty.ancestry.place_type.place_types.Department`)

  A department.

`district` (`betty.ancestry.place_type.place_types.District`)

  A district.

`farm` (`betty.ancestry.place_type.place_types.Farm`)

  A farm.

`hamlet` (`betty.ancestry.place_type.place_types.Hamlet`)

  A hamlet.

`locality` (`betty.ancestry.place_type.place_types.Locality`)

  A locality.

`municipality` (`betty.ancestry.place_type.place_types.Municipality`)

  A municipality.

`neighborhood` (`betty.ancestry.place_type.place_types.Neighborhood`)

  A neighborhood.

`number` (`betty.ancestry.place_type.place_types.Number`)

  A (house) number.

`parish` (`betty.ancestry.place_type.place_types.Parish`)

  A parish.

`province` (`betty.ancestry.place_type.place_types.Province`)

  A province.

`region` (`betty.ancestry.place_type.place_types.Region`)

  A region.

`state` (`betty.ancestry.place_type.place_types.State`)

  A state.

`street` (`betty.ancestry.place_type.place_types.Street`)

  A street.

`town` (`betty.ancestry.place_type.place_types.Town`)

  A town.

`unknown` (`betty.ancestry.place_type.place_types.Unknown`)

  A place of an unknown type.

`village` (`betty.ancestry.place_type.place_types.Village`)

  A village.

## See also

- Place type plugins